@@ -159,3 +159,71 @@ getPageFields <- function(crawlId) {
 
 
 }
+
+
+#' Get Aggregate Queries for a specific OQL
+#'
+#' @param crawlId ID of your crawl
+#' @param oqlList json of your OQL
+#'
+#' @details
+#' <http://developer.oncrawl.com/#OnCrawl-Query-Language>
+#'
+#' ResCode
+#' 400 : Returned when the request has incompatible values or does not match the API specification.
+#' 401 : Returned when the request is not authenticated.
+#' 403 : Returned the current quota does not allow the action to be performed.
+#' 404 : Returned when any of resource(s) referred in the request is not found.
+#' 403 : Returned when the request is authenticated but the action is not allowed.
+#' 409 : Returned when the requested operation is not allowed for current state of the resource.
+#' 500 : Internal error
+#'
+#' @examples
+#' \dontrun{
+#' agg <- listPagesAggs(YOURCRAWLID, YOURJSON)
+#' page_crawled = agg[[1]]$rows
+#' }
+#'
+#' @return Json
+#' @author Vincent Terrasi
+#' @export
+listPagesAggs <- function(crawlId,oqlList) {
+
+  KEY <- getOption('oncrawl_token')
+  DEBUG <- getOption('oncrawl_debug')
+  API <- getOption('oncrawl_api')
+
+  if(nchar(KEY)<=10) {
+    testConf <- initAPI()
+    if(testConf!="ok") stop("No API Key detected")
+  }
+
+  curl <- RCurl::getCurlHandle()
+
+  pageAPI <- paste0(API,"data/crawl/", crawlId,"/pages/aggs", sep = "")
+
+  hdr  <- c('Content-Type'="application/json"
+            ,Authorization=paste("Bearer",KEY)
+  )
+
+  reply <- RCurl::postForm(pageAPI,
+                           .opts=list(httpheader=hdr, postfields=oqlList),
+                           curl = curl,
+                           style = "POST"
+  )
+
+  info <- RCurl::getCurlInfo(curl)
+
+  if (info$response.code==200) {
+    # return ok if response.code==200
+    json <- rjson::fromJSON(reply)
+    data <- json$aggs
+
+  } else {
+    # return error if response.code!=200
+    warning(reply)
+  }
+
+  return(data)
+}
+
